@@ -2,7 +2,7 @@ use crate::error::{FendError, Interrupt};
 use crate::eval::evaluate_to_value;
 use crate::ident::Ident;
 use crate::interrupt::test_int;
-use crate::num::{Base, FormattingStyle, Number};
+use crate::num::{Base, FormattingStyle, Number, Range, RangeBound};
 use crate::result::FResult;
 use crate::scope::Scope;
 use crate::serialize::{Deserialize, Serialize};
@@ -509,7 +509,7 @@ pub(crate) fn evaluate<I: Interrupt>(
 		}
 		Expr::Equality(is_equals, a, b) => {
 			let lhs = evaluate(*a, scope.clone(), attrs, context, int)?;
-			let rhs = evaluate(*b, scope.clone(), attrs, context, int)?;
+			let rhs = evaluate(*b, scope, attrs, context, int)?;
 			Value::Bool(match lhs.compare(&rhs, int)? {
 				Some(cmp::Ordering::Equal) => is_equals,
 				Some(cmp::Ordering::Greater | cmp::Ordering::Less) | None => !is_equals,
@@ -628,6 +628,16 @@ fn evaluate_as<I: Interrupt>(
 				if a == 0 {
 					return Err(FendError::RomanNumeralZero);
 				}
+				let upper_limit = 100_000;
+				if a > upper_limit {
+					return Err(FendError::OutOfRange {
+						value: Box::new(a),
+						range: Range {
+							start: RangeBound::Closed(Box::new(1)),
+							end: RangeBound::Closed(Box::new(upper_limit)),
+						},
+					});
+				}
 				return Ok(Value::String(borrow::Cow::Owned(to_roman(a))));
 			}
 			_ => (),
@@ -696,6 +706,7 @@ pub(crate) fn resolve_identifier<I: Interrupt>(
 		"true" => Value::Bool(true),
 		"false" => Value::Bool(false),
 		"sample" | "roll" => Value::BuiltInFunction(BuiltInFunction::Sample),
+		"mean" | "average" => Value::BuiltInFunction(BuiltInFunction::Mean),
 		"sqrt" => evaluate_to_value("x: x^(1/2)", scope, attrs, context, int)?,
 		"cbrt" => evaluate_to_value("x: x^(1/3)", scope, attrs, context, int)?,
 		"real" | "re" | "Re" => Value::BuiltInFunction(BuiltInFunction::Real),
