@@ -5935,4 +5935,28 @@ fn test_roman() {
 	test_eval_simple("3456 to roman", "MMMCDLVI");
 	test_eval_simple("1452 to roman", "MCDLII");
 	test_eval_simple("20002 to roman", "MMMMMMMMMMMMMMMMMMMMII");
+	expect_error(
+		"100001 to roman",
+		Some("100001 must lie in the interval [1, 100000]"),
+	);
+}
+
+#[test]
+fn rack_unit() {
+	test_eval("4U to cm", "17.78 cm");
+}
+
+#[test]
+fn test_mean() {
+	test_eval("mean d1", "1");
+	test_eval("mean d2", "1.5");
+	test_eval("mean d500", "250.5");
+
+	test_eval("mean (d1 + d1)", "2");
+	test_eval("mean (d2 + d500)", "252");
+
+	test_eval("mean (d6 / d2)", "2.625");
+	test_eval("mean (d10 / d2)", "4.125");
+
+	test_eval("average d500", "250.5");
 }
